"""
Main interface for healthlake service.

Usage::

    ```python
    import boto3
    from mypy_boto3_healthlake import (
        Client,
        HealthLakeClient,
    )

    session = boto3.Session()

    client: HealthLakeClient = boto3.client("healthlake")
    session_client: HealthLakeClient = session.client("healthlake")
    ```
"""
from mypy_boto3_healthlake.client import HealthLakeClient

Client = HealthLakeClient

__all__ = ("Client", "HealthLakeClient")



"""
Main interface for healthlake service type definitions.

Usage::

    ```python
    from mypy_boto3_healthlake.type_defs import DatastorePropertiesTypeDef

    data: DatastorePropertiesTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "DatastorePropertiesTypeDef",
    "ExportJobPropertiesTypeDef",
    "ImportJobPropertiesTypeDef",
    "InputDataConfigTypeDef",
    "OutputDataConfigTypeDef",
    "PreloadDataConfigTypeDef",
    "CreateFHIRDatastoreResponseTypeDef",
    "DatastoreFilterTypeDef",
    "DeleteFHIRDatastoreResponseTypeDef",
    "DescribeFHIRDatastoreResponseTypeDef",
    "DescribeFHIRExportJobResponseTypeDef",
    "DescribeFHIRImportJobResponseTypeDef",
    "ListFHIRDatastoresResponseTypeDef",
    "StartFHIRExportJobResponseTypeDef",
    "StartFHIRImportJobResponseTypeDef",
)

_RequiredDatastorePropertiesTypeDef = TypedDict(
    "_RequiredDatastorePropertiesTypeDef",
    {
        "DatastoreId": str,
        "DatastoreArn": str,
        "DatastoreStatus": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
        "DatastoreTypeVersion": Literal["R4"],
        "DatastoreEndpoint": str,
    },
)
_OptionalDatastorePropertiesTypeDef = TypedDict(
    "_OptionalDatastorePropertiesTypeDef",
    {"DatastoreName": str, "CreatedAt": datetime, "PreloadDataConfig": "PreloadDataConfigTypeDef"},
    total=False,
)


class DatastorePropertiesTypeDef(
    _RequiredDatastorePropertiesTypeDef, _OptionalDatastorePropertiesTypeDef
):
    pass


_RequiredExportJobPropertiesTypeDef = TypedDict(
    "_RequiredExportJobPropertiesTypeDef",
    {
        "JobId": str,
        "JobStatus": Literal["SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED"],
        "SubmitTime": datetime,
        "DatastoreId": str,
        "OutputDataConfig": "OutputDataConfigTypeDef",
    },
)
_OptionalExportJobPropertiesTypeDef = TypedDict(
    "_OptionalExportJobPropertiesTypeDef",
    {"JobName": str, "EndTime": datetime, "DataAccessRoleArn": str, "Message": str},
    total=False,
)


class ExportJobPropertiesTypeDef(
    _RequiredExportJobPropertiesTypeDef, _OptionalExportJobPropertiesTypeDef
):
    pass


_RequiredImportJobPropertiesTypeDef = TypedDict(
    "_RequiredImportJobPropertiesTypeDef",
    {
        "JobId": str,
        "JobStatus": Literal["SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED"],
        "SubmitTime": datetime,
        "DatastoreId": str,
        "InputDataConfig": "InputDataConfigTypeDef",
    },
)
_OptionalImportJobPropertiesTypeDef = TypedDict(
    "_OptionalImportJobPropertiesTypeDef",
    {"JobName": str, "EndTime": datetime, "DataAccessRoleArn": str, "Message": str},
    total=False,
)


class ImportJobPropertiesTypeDef(
    _RequiredImportJobPropertiesTypeDef, _OptionalImportJobPropertiesTypeDef
):
    pass


InputDataConfigTypeDef = TypedDict("InputDataConfigTypeDef", {"S3Uri": str}, total=False)

OutputDataConfigTypeDef = TypedDict("OutputDataConfigTypeDef", {"S3Uri": str}, total=False)

PreloadDataConfigTypeDef = TypedDict(
    "PreloadDataConfigTypeDef", {"PreloadDataType": Literal["SYNTHEA"]}
)

CreateFHIRDatastoreResponseTypeDef = TypedDict(
    "CreateFHIRDatastoreResponseTypeDef",
    {
        "DatastoreId": str,
        "DatastoreArn": str,
        "DatastoreStatus": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
        "DatastoreEndpoint": str,
    },
)

DatastoreFilterTypeDef = TypedDict(
    "DatastoreFilterTypeDef",
    {
        "DatastoreName": str,
        "DatastoreStatus": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
        "CreatedBefore": datetime,
        "CreatedAfter": datetime,
    },
    total=False,
)

DeleteFHIRDatastoreResponseTypeDef = TypedDict(
    "DeleteFHIRDatastoreResponseTypeDef",
    {
        "DatastoreId": str,
        "DatastoreArn": str,
        "DatastoreStatus": Literal["CREATING", "ACTIVE", "DELETING", "DELETED"],
        "DatastoreEndpoint": str,
    },
)

DescribeFHIRDatastoreResponseTypeDef = TypedDict(
    "DescribeFHIRDatastoreResponseTypeDef", {"DatastoreProperties": "DatastorePropertiesTypeDef"}
)

DescribeFHIRExportJobResponseTypeDef = TypedDict(
    "DescribeFHIRExportJobResponseTypeDef", {"ExportJobProperties": "ExportJobPropertiesTypeDef"}
)

DescribeFHIRImportJobResponseTypeDef = TypedDict(
    "DescribeFHIRImportJobResponseTypeDef", {"ImportJobProperties": "ImportJobPropertiesTypeDef"}
)

_RequiredListFHIRDatastoresResponseTypeDef = TypedDict(
    "_RequiredListFHIRDatastoresResponseTypeDef",
    {"DatastorePropertiesList": List["DatastorePropertiesTypeDef"]},
)
_OptionalListFHIRDatastoresResponseTypeDef = TypedDict(
    "_OptionalListFHIRDatastoresResponseTypeDef", {"NextToken": str}, total=False
)


class ListFHIRDatastoresResponseTypeDef(
    _RequiredListFHIRDatastoresResponseTypeDef, _OptionalListFHIRDatastoresResponseTypeDef
):
    pass


_RequiredStartFHIRExportJobResponseTypeDef = TypedDict(
    "_RequiredStartFHIRExportJobResponseTypeDef",
    {"JobId": str, "JobStatus": Literal["SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED"]},
)
_OptionalStartFHIRExportJobResponseTypeDef = TypedDict(
    "_OptionalStartFHIRExportJobResponseTypeDef", {"DatastoreId": str}, total=False
)


class StartFHIRExportJobResponseTypeDef(
    _RequiredStartFHIRExportJobResponseTypeDef, _OptionalStartFHIRExportJobResponseTypeDef
):
    pass


_RequiredStartFHIRImportJobResponseTypeDef = TypedDict(
    "_RequiredStartFHIRImportJobResponseTypeDef",
    {"JobId": str, "JobStatus": Literal["SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED"]},
)
_OptionalStartFHIRImportJobResponseTypeDef = TypedDict(
    "_OptionalStartFHIRImportJobResponseTypeDef", {"DatastoreId": str}, total=False
)


class StartFHIRImportJobResponseTypeDef(
    _RequiredStartFHIRImportJobResponseTypeDef, _OptionalStartFHIRImportJobResponseTypeDef
):
    pass



"""
Main interface for healthlake service client

Usage::

    ```python
    import boto3
    from mypy_boto3_healthlake import HealthLakeClient

    client: HealthLakeClient = boto3.client("healthlake")
    ```
"""
import sys
from typing import Any, Dict, Type

from botocore.client import ClientMeta

from mypy_boto3_healthlake.type_defs import (
    CreateFHIRDatastoreResponseTypeDef,
    DatastoreFilterTypeDef,
    DeleteFHIRDatastoreResponseTypeDef,
    DescribeFHIRDatastoreResponseTypeDef,
    DescribeFHIRExportJobResponseTypeDef,
    DescribeFHIRImportJobResponseTypeDef,
    InputDataConfigTypeDef,
    ListFHIRDatastoresResponseTypeDef,
    OutputDataConfigTypeDef,
    PreloadDataConfigTypeDef,
    StartFHIRExportJobResponseTypeDef,
    StartFHIRImportJobResponseTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = ("HealthLakeClient",)

class BotocoreClientError(BaseException):
    MSG_TEMPLATE: str
    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
        self.response: Dict[str, Any]
        self.operation_name: str

class Exceptions:
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class HealthLakeClient:
    """
    [HealthLake.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client)
    """

    meta: ClientMeta
    exceptions: Exceptions
    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.can_paginate)
        """
    def create_fhir_datastore(
        self,
        DatastoreTypeVersion: Literal["R4"],
        DatastoreName: str = None,
        PreloadDataConfig: "PreloadDataConfigTypeDef" = None,
        ClientToken: str = None,
    ) -> CreateFHIRDatastoreResponseTypeDef:
        """
        [Client.create_fhir_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.create_fhir_datastore)
        """
    def delete_fhir_datastore(self, DatastoreId: str = None) -> DeleteFHIRDatastoreResponseTypeDef:
        """
        [Client.delete_fhir_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.delete_fhir_datastore)
        """
    def describe_fhir_datastore(
        self, DatastoreId: str = None
    ) -> DescribeFHIRDatastoreResponseTypeDef:
        """
        [Client.describe_fhir_datastore documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.describe_fhir_datastore)
        """
    def describe_fhir_export_job(
        self, DatastoreId: str, JobId: str
    ) -> DescribeFHIRExportJobResponseTypeDef:
        """
        [Client.describe_fhir_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.describe_fhir_export_job)
        """
    def describe_fhir_import_job(
        self, DatastoreId: str, JobId: str
    ) -> DescribeFHIRImportJobResponseTypeDef:
        """
        [Client.describe_fhir_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.describe_fhir_import_job)
        """
    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.generate_presigned_url)
        """
    def list_fhir_datastores(
        self, Filter: DatastoreFilterTypeDef = None, NextToken: str = None, MaxResults: int = None
    ) -> ListFHIRDatastoresResponseTypeDef:
        """
        [Client.list_fhir_datastores documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.list_fhir_datastores)
        """
    def start_fhir_export_job(
        self,
        OutputDataConfig: "OutputDataConfigTypeDef",
        DatastoreId: str,
        DataAccessRoleArn: str,
        ClientToken: str,
        JobName: str = None,
    ) -> StartFHIRExportJobResponseTypeDef:
        """
        [Client.start_fhir_export_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.start_fhir_export_job)
        """
    def start_fhir_import_job(
        self,
        InputDataConfig: "InputDataConfigTypeDef",
        DatastoreId: str,
        DataAccessRoleArn: str,
        ClientToken: str,
        JobName: str = None,
    ) -> StartFHIRImportJobResponseTypeDef:
        """
        [Client.start_fhir_import_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.41/reference/services/healthlake.html#HealthLake.Client.start_fhir_import_job)
        """
